@@ -18,38 +18,37 @@ NULL
 #' @return A header function.
 #' @noRd
 recipient <- function(key, single = FALSE) {
-  force(key)                                                       # nocov start
+  force(key) # nocov start
   force(single)
 
   if (single) {
-    function(msg, addr = NULL, split = ", *") {
+    function(msg, addr = NULL) {
       if (is.null(addr)) {
         header_get(msg, key)
       } else {
-        addr <- as.address(addr, split = split)
+        addr <- as.address(addr)
         if (length(addr) > 1) stop("Only one address allowed.")
         msg <- header_set(msg, key, addr, append = FALSE)
         if (get_option_invisible()) invisible(msg) else msg
       }
     }
   } else {
-    function(msg, ..., append = TRUE, split = ", *") {
+    function(msg, ..., append = TRUE) {
       addr <- list(...)
       if (length(addr)) {
-        addr <- map(addr, as.address, split = split) %>% do.call(c, .)
+        addr <- map(addr, as.address) %>% do.call(c, .)
         msg <- header_set(msg, key, addr, append = append, sep = ",")
         if (get_option_invisible()) invisible(msg) else msg
       } else {
         header_get(msg, key)
       }
     }
-  }                                                                # nocov end
+  } # nocov end
 }
 
 #' @rdname addresses
 #'
 #' @param ... Addresses.
-#' @inheritParams as.address
 #'
 #' @export
 #' @examples
@@ -127,9 +126,16 @@ sender <- recipient("Sender", TRUE)
 
 #' Add or query subject of message.
 #'
+#' @details
+#' The `prefix` and `suffix` can be used to add extra
+#' \href{https://en.wikipedia.org/wiki/List_of_email_subject_abbreviations}{subject
+#' abbreviations}.
+#'
 #' @inheritParams text
 #' @param msg A message object.
 #' @param subject A subject for the message.
+#' @param prefix A subject prefix.
+#' @param suffix A subject suffix.
 #'
 #' @return A message object or the subject of the message object (if \code{subject} is \code{NULL}).
 #' @seealso \code{\link{to}}, \code{\link{from}}, \code{\link{cc}}, \code{\link{bcc}} and \code{\link{reply}}
@@ -140,23 +146,29 @@ sender <- recipient("Sender", TRUE)
 #'
 #' # Retrieve the subject for a message
 #' subject(msg)
-subject <- function(
-  msg,
-  subject = NULL,
-  interpolate = TRUE,
-  .open = "{{",
-  .close = "}}",
-  .envir = NULL
-) {
+subject <- function(msg,
+                    subject = NULL,
+                    prefix = NA,
+                    suffix = NA,
+                    interpolate = TRUE,
+                    .open = "{{",
+                    .close = "}}",
+                    .envir = NULL) {
   if (is.null(subject)) {
     header_get(msg, "Subject")
   } else {
-    if (is.null(.envir)) .envir = parent.frame()
-    else .envir = list2env(.envir)
+    if (is.null(.envir)) {
+      .envir <- parent.frame()
+    } else {
+      .envir <- list2env(.envir)
+    }
+
+    if (!is.na(prefix)) subject <- paste(prefix, subject)
+    if (!is.na(suffix)) subject <- paste(subject, suffix)
 
     if (interpolate) subject <- glue(subject, .open = .open, .close = .close, .envir = .envir)
 
-    msg <- header_set(msg, "Subject", subject, append = FALSE)
+    msg <- header_set(msg, "Subject", encodable(subject), append = FALSE)
     if (get_option_invisible()) invisible(msg) else msg # nocov
   }
 }
@@ -244,7 +256,7 @@ comments <- function(msg, comments = NULL) {
 #' msg <- envelope() %>% keywords("newsletter, marketing")
 #' keywords(msg)
 keywords <- function(msg, ..., append = FALSE) {
-   arguments <- c(...)
+  arguments <- c(...)
   if (is.null(arguments)) {
     header_get(msg, "Keywords")
   } else {
